//
// Developed by Michael Russo
// Copyright (c) 2018-2022 DynaMount LLC
// All Rights Reserved.
//

const {app, Menu, BrowserWindow, shell, ipcMain} = require('electron');
const path = require('path');
const url = require('url');

const template = [
	{
		label: 'Edit',
		submenu: [
			{role: 'undo'},
			{role: 'redo'},
			{type: 'separator'},
			{role: 'cut'},
			{role: 'copy'},
			{role: 'paste'},
			{role: 'pasteandmatchstyle'},
			{role: 'delete'},
			{role: 'selectall'}
		]
	},
	{
		label: 'View',
		submenu: [
			{role: 'reload'},
			{role: 'forcereload'},
			{role: 'toggledevtools'},
			{type: 'separator'},
			{role: 'resetzoom'},
			{role: 'zoomin'},
			{role: 'zoomout'},
			{type: 'separator'},
			{role: 'togglefullscreen'}
		]
	},
	{
		role: 'window',
		submenu: [
			{role: 'minimize'},
			{role: 'close'}
		]
	},
	{
		role: 'help',
		submenu: [
			{
				label: 'Learn More',
				click () { require('electron').shell.openExternal('https://dynamount.com/support/') }
			}
		]
	}
];

if (process.platform === 'darwin') {
	template.unshift({
		label: app.getName(),
		submenu: [
			{role: 'about'},
			{type: 'separator'},
			{role: 'services', submenu: []},
			{type: 'separator'},
			{role: 'hide'},
			{role: 'hideothers'},
			{role: 'unhide'},
			{type: 'separator'},
			{role: 'quit'}
		]
	});

	template[1].submenu.push(
		{type: 'separator'},
		{
			label: 'Speech',
			submenu: [
				{role: 'startspeaking'},
				{role: 'stopspeaking'}
			]
		}
	);

	template[3].submenu = [
		{role: 'close'},
		{role: 'minimize'},
		{role: 'zoom'},
		{type: 'separator'},
		{role: 'front'}
	];
}



ipcMain.handle('user-data-path', async (event) => {
  return app.getPath('userData');
});

ipcMain.handle('app-is-packaged', async (event) => {
  return app.isPackaged;
});


let win;

function createWindow() {
	win = new BrowserWindow({
		width: 1100,
		height: 800,
		icon: path.join(__dirname, 'build/icons/png/64x64.png'),
		webPreferences: {
			devTools: false,
            nodeIntegration: true,
			contextIsolation: false,
            preload: path.join(__dirname, 'preload.js')
        }
	});

	win.loadURL(url.format({
		pathname: path.join(__dirname, 'src/index.html'),
		protocol: 'file:',
		slashes: true
	}));
	
	
	
	
	
	const menu = Menu.buildFromTemplate(template);
	Menu.setApplicationMenu(menu);

	win.on('closed', () => {
		win = null;
	});
	
	win.webContents.on('new-window', function(e, url) {
		e.preventDefault();
		shell.openExternal(url);
	});
}


app.allowRendererProcessReuse = false;

app.on('ready', createWindow);

app.on('window-all-closed', () => {
	
	if (process.platform !== 'darwin') {
		app.quit();
	}
});

app.on('activate', () => {
	if (win === null) {
		createWindow();
	}
});


app.on('certificate-error', (event, webContents, url, error, certificate, callback) => {
	event.preventDefault();
	callback(true);
});


process.on('uncaughtException', function (exception) {

	
});

